#!/usr/bin/env python

import wx

class MainFrame(wx.Frame):
    """Class with the GUI and GUI functions"""
    def __init__(self, parent,id):
        """Displays the frame, creates the GUI"""
        wx.Frame.__init__(self, parent,id, "Draw Line Example", 
                          size=(300,200), style=wx.CAPTION | wx.CLOSE_BOX)
        sizer= wx.BoxSizer(wx.VERTICAL)
        self.SetSizer(sizer)
        panel= Panel(self)
        sizer.Add(panel, 1, wx.EXPAND)
        self.Layout()

class Panel(wx.Panel):
    """Class with the main panel and its functions"""
    line_x = 1 #X position of line
    going_left = False
    going_right = True #The line goes to the right first
    
    def __init__(self, parent):
        """Defines bindings and sets the panel up"""
        super(Panel, self).__init__(parent)  #super the panel
        self.Bind(wx.EVT_PAINT, self.OnPaint)
        
        #Create the timer
        self.timer = wx.Timer(self)
        self.Bind(wx.EVT_TIMER, self.Update, self.timer)
        self.timer.Start(50) #Updates Every 50 miliseconds
    
    def Update(self, event):
        """Update function, always being called"""
        self.dc.Clear() #Clear dc
        self.dc.DrawLine(self.line_x, 0, self.line_x, 200) #Draw line
        #Check if it reached the parent's size width
        #Or if it hit the left border
        if self.line_x == self.GetParent().GetSize()[0] or self.line_x==0:
            #Reverse directions
            self.going_left = not self.going_left
            self.going_right = not self.going_right
        if self.going_left:
            self.line_x -= 1 #Go to the left
        else:
            self.line_x += 1 #Go to the right
    
    def OnPaint(self, event):
        """Is called with EVT_PAINT, draws a line"""
        self.dc = wx.PaintDC(self)  #Creates the wxPaintDC
        self.dc.Clear()  #Clears (to white) the wxPaintDC

if __name__=='__main__':
    """Displays the GUI and starts the GUI Loop"""
    app = wx.PySimpleApp()
    frame = MainFrame(parent=None, id=-1)
    frame.Show()
    app.MainLoop()

